##  Linking Discovered Items to Fact Sheets
After you set up the integration, the discovery process identifies your MCP servers and lists them in the AI agent discovery inbox. In the inbox, you can filter MCP servers using the Classification filter. Review the discovered items and link them to existing fact sheets, or create and link new fact sheets. For more information, refer to [AI Agent Discovery Inbox](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD "AI agents and MCP servers discovered across your enterprise landscape appear in the AI agent discovery inbox. Learn how to review, link, and reject fact sheets related to discovered items.").
